#
# spec file for package python-jupyter_console
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jupyter_console
Version:        6.6.3
Release:        1.2
Summary:        Jupyter terminal console
License:        BSD-3-Clause
URL:            https://github.com/jupyter/jupyter_console
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter_console/jupyter_console-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatchling >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module ipykernel >= 6.14}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module jupyter-client >= 7}
BuildRequires:  %{python_module jupyter-core >= 5.1}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module prompt_toolkit >= 3.0.30}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyzmq >= 17}
BuildRequires:  %{python_module traitlets >= 5.4}
# /SECTION
Requires:       jupyter-jupyter_console = %{version}
Requires:       python-Pygments
Requires:       python-ipykernel >= 6.14
Requires:       python-ipython
Requires:       python-jupyter-client >= 7
Requires:       python-prompt_toolkit >= 3.0.30
Requires:       python-pyzmq >= 17
Requires:       python-traitlets >= 5.4
Requires:       ((python-jupyter-core >= 4.12 with python-jupyter-core < 5.0) or python-jupyter-core >= 5.1)
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-jupyter-console = %{version}-%{release}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       jupyter-jupyter_console = %{version}-%{release}
Obsoletes:      jupyter-jupyter_console < %{version}-%{release}
Provides:       jupyter-jupyter_console-doc = %{version}-%{release}
Obsoletes:      jupyter-jupyter_console-doc < %{version}-%{release}
%endif
BuildArch:      noarch
%python_subpackages

%description
A terminal-based console frontend for Jupyter kernels.
This code is based on the single-process IPython terminal.

%prep
%setup -q -n jupyter_console-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jupyter-console
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -s --force-flaky --max-runs=10

%post
%python_install_alternative jupyter-console

%postun
%python_uninstall_alternative jupyter-console

%files %{python_files}
%doc CONTRIBUTING.md README.md
%license LICENSE
%python_alternative %{_bindir}/jupyter-console
%{python_sitelib}/jupyter_console
%{python_sitelib}/jupyter_console-%{version}*-info

%changelog
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.6.3
  * Fix handle_external_iopub again #286 (@blink1073)
- Release 6.6.2
  * Fix handle_external_iopub #285 (@blink1073)
- Release 6.6.0
  * Switch to hatch backend #281 (@blink1073)
- Release 6.5.1
  * Fix completion handling #278 (@blink1073)
- Release 6.5.0
  * Fix client 7 and 8 compat #276 (@blink1073)
* Mon Aug  1 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.4.4
  * Use asyncio.create_task and asyncio.get_running_loop with
    interact().
  * Drop Python 3.6. #270 (@encukou)
* Sun Mar 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.4.3
  * Require jupyter_client>=7.0.0
  * Don't pass loop to asyncio.wait()
  * Prepare for use with Jupyter Releaser
* Wed Apr 14 2021 Ben Greiner <code@bnavigator.de>
- Update to 6.4.0
  * no release notes
- Drop python-jupyter_console-remove-nose.patch merged upstream
* Wed Feb 10 2021 Benjamin Greiner <code@bnavigator.de>
- Force to import setuptools so that we get the entrypoint
  gh#jupyter/jupyter_console#222
- Install entrypoint under update-alternatives control
- Drop empty jupyter-jupyter_console package, provide it in primary
  python3 package
* Fri Oct  2 2020 pgajdos@suse.com
- before test drop, try more runs for --flaky
* Tue Sep 15 2020 pgajdos@suse.com
- replace nose by pytest
- added patches
  https://github.com/jupyter/jupyter_console/pull/230
  + python-jupyter_console-remove-nose.patch
* Sun May 17 2020 Benjamin Greiner <code@bnavigator.de>
- Add Pillow to test build, avoids skipping a test
- Force all tests to be flaky, because they timeout occasionally
  on OBS
* Sat May 16 2020 Benjamin Greiner <code@bnavigator.de>
- do not capture stdout to pass the tests
  gh#jupyter/jupyter_console#214
* Tue Jan 28 2020 Todd R <toddrme2178@gmail.com>
- Update to 6.1.0
  * switch bumpversion to nbformat-style
  * Remove Python 2 compatibility code.
  * Add support for prompt-toolkit v3
  * removed extra lines from the banner
- Drop documentation.
  These are mostly a relic of when the tests needed to be in a
  separate package, and since the docs are no longer versioned
  upstream keeping them synced with the main package is difficult.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- jupyter_client renamed to jupyter-client
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Enable tests
* Fri May 17 2019 Todd R <toddrme2178@gmail.com>
- Split jupyter components into own subpackage.
* Tue Oct 16 2018 Todd R <toddrme2178@gmail.com>
- Update to version 6.0.0
  * Drop support for python 2
  * Upgrade to prompt_toolkit 2.x
- Don't build for python2 anymore since it isn't supported.
* Sun Oct  7 2018 Todd R <toddrme2178@gmail.com>
- Use upstream builds of doc files.
- Merge doc subpackage and tests into main spec file.
- Use %%license tag
- Fix prompt_toolkit dependency.
* Sun Jul 22 2018 toddrme2178@gmail.com
- Not compatible with prompt_toolkit 2.x
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.2.0
  * When using a kernel that the console did not start, exiting with Ctrl-D now
    leaves it running.
  * Added Ctrl-\\ shortcut to quit the console.
  * Input prompt numbers are now updated when another frontend has executed
    code in the same kernel.
  * Fix setting next input with newer versions of prompt_toolkit.
  * Ensure history entries are unicode, not bytes, on Python 2.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Mar 31 2017 toddrme2178@gmail.com
- Updaste to 5.1
  * New ``ZMQTerminalInteractiveShell.true_color`` config option to use 24-bit
  colour.
  * New ``ZMQTerminalInteractiveShell.confirm_exit`` config option to turn off
  asking 'are you sure' on exit.
  * New ``--simple-prompt`` flag to explicitly use the fallback mode without
  prompt_toolkit.
  * Fixed executing an empty input.
  * Fixed formatting for code and outputs from other frontends executing code.
  * Avoid using functions which will be removed in IPython 6.
- Updaste to 5.0.0
  + Interactive Shell architecture
  * disinherit shell class from IPython Interactive Shell `#68 <https://github.com/jupyter/jupyter_console/pull/68>`_
    This separates jupyter_console's ZMQTerminalInteractiveShell from IPython's TerminalInteractiveShell and InteractiveShell classes.
  * update SIGINT handler to not use the old interactive API shell `#80 <https://github.com/jupyter/jupyter_console/pull/80>`_
  + Image Handling improvement
  * use PIL as default image handler `#79 <https://github.com/jupyter/jupyter_console/pull/79>`_
  * better indication of whether image data was handled `#77 <https://github.com/jupyter/jupyter_console/pull/77>`_
  + Prompts improvement
  * use prompt_toolkit 1.0 `#74 <https://github.com/jupyter/jupyter_console/pull/74>`_
  * don't use prompt_manager `#75 <https://github.com/jupyter/jupyter_console/pull/75>`_
  * remove ``colors_force`` flag that have no effects: `#88 <https://github.com/jupyter/jupyter_console/pull/88>`_
- Updaste to 4.1.1
  * fix for readline history
  * don't confuse sys.path with virtualenvs
* Thu Feb 18 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
  * Split documentation into subpackage
- update to version 4.1.0:
  * readline/completion fixes
  * use is_complete messages to determine if input is complete
    (important for non-Python kernels)
  * fix: 4.0 was looking for jupyter_console_config in IPython config
    directories, not Jupyter
* Mon Oct 12 2015 toddrme2178@gmail.com
- Update to 4.0.3
  * fix jupyter console --generate-config
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 16 2015 toddrme2178@gmail.com
- Update to 4.0.2
  * fix `jupyter console --generate-config`
  * add long_description
  * fix setuptools entrypoint
- Update to 4.0.1
  * entrypoints only when setuptools invoked
  * bug fix
  * suggestion for windows users
  * Fix printing errors when execute_reply and error messages come
  * Try installing IPython from Github on RTD
  * Try installing on RTD with --pre to get IPython 4
  * Add requirements file for RTD
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
